@@ -200,29 +200,22 @@ _gtk_request_dialog_run (GtkWindow        *parent,
 	GtkWidget    *entry;
 	GtkWidget    *button;
 	GtkWidget    *content_area;
-	char         *stock_id;
 	char         *result;
 
-	stock_id = GTK_STOCK_DIALOG_QUESTION;
-
 	dialog = gtk_dialog_new_with_buttons (title, parent, flags, NULL, NULL);
 	content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 
 	/* Add label and image */
 
-	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_DIALOG);
+	image = gtk_image_new_from_icon_name ("dialog-question", GTK_ICON_SIZE_DIALOG);
 	gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
 	gtk_widget_set_valign (image, GTK_ALIGN_START);
 
 	label = gtk_label_new_with_mnemonic (message);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (label), FALSE);
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
 	gtk_label_set_yalign (GTK_LABEL (label), 0.0);
-#else
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
-#endif
 
 	entry = gtk_entry_new ();
 	gtk_entry_set_width_chars (GTK_ENTRY (entry), 50);
@@ -291,7 +284,6 @@ _gtk_yesno_dialog_new (GtkWindow        *parent,
 	GtkWidget    *hbox;
 	GtkWidget    *button;
 	GtkWidget    *content_area;
-	char         *stock_id = GTK_STOCK_DIALOG_WARNING;
 
 	d = gtk_dialog_new_with_buttons ("", parent, flags, NULL, NULL);
 	gtk_window_set_resizable (GTK_WINDOW (d), FALSE);
@@ -300,7 +292,7 @@ _gtk_yesno_dialog_new (GtkWindow        *parent,
 
 	/* Add label and image */
 
-	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_DIALOG);
+	image = gtk_image_new_from_icon_name ("dialog-warning", GTK_ICON_SIZE_DIALOG);
 	gtk_widget_set_valign (image, GTK_ALIGN_START);
 
 	label = gtk_label_new (message);
@@ -364,14 +356,11 @@ _gtk_error_dialog_new (GtkWindow        *parent,
 	GtkWidget     *action_area;
 	GtkTextBuffer *text_buf;
 	GtkTextIter    iter;
-	char          *stock_id;
 	GList         *scan;
 	char          *escaped_message, *markup_text;
 	va_list        args;
 	gboolean       view_output = (row_output != NULL);
 
-	stock_id = GTK_STOCK_DIALOG_ERROR;
-
 	dialog = gtk_dialog_new_with_buttons ("",
 					      parent,
 					      flags,
@@ -386,19 +375,15 @@ _gtk_error_dialog_new (GtkWindow        *parent,
 
 	/* Add label and image */
 
-	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_DIALOG);
+	image = gtk_image_new_from_icon_name ("dialog-error", GTK_ICON_SIZE_DIALOG);
 	gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
 	gtk_widget_set_valign (image, GTK_ALIGN_START);
 
 	label = gtk_label_new ("");
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
 	gtk_label_set_yalign (GTK_LABEL (label), 0.0);
-#else
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
-#endif
 
 	escaped_message = g_markup_escape_text (primary_text, -1);
 	if (secondary_text != NULL) {
@@ -733,26 +718,11 @@ get_folder_pixbuf_size_for_list (GtkWidget *widget)
 {
 	int icon_width, icon_height;
 
-	gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (widget),
-					   GTK_ICON_SIZE_SMALL_TOOLBAR,
-					   &icon_width, &icon_height);
+	gtk_icon_size_lookup (GTK_ICON_SIZE_SMALL_TOOLBAR,
+			      &icon_width, &icon_height);
 	return MAX (icon_width, icon_height);
 }
 
-gboolean
-show_uri (GdkScreen   *screen,
-	  const char  *uri,
-	  guint32      timestamp,
-	  GError     **error)
-{
-	gboolean result;
-
-	result = gtk_show_uri (screen, uri, timestamp, error);
-
-	return result;
-}
-
-
 void
 show_help_dialog (GtkWindow  *parent,
 		  const char *section)
@@ -761,8 +731,8 @@ show_help_dialog (GtkWindow  *parent,
 	GError *error = NULL;
 
 	uri = g_strconcat ("help:engrampa", section ? "/" : NULL, section, NULL);
-	if (! show_uri (gtk_window_get_screen (parent), uri, GDK_CURRENT_TIME, &error)) {
-  		GtkWidget *dialog;
+	if (! gtk_show_uri_on_window (parent, uri, GDK_CURRENT_TIME, &error)) {
+		GtkWidget *dialog;
 
 		dialog = _gtk_message_dialog_new (parent,
 						  GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -836,8 +806,7 @@ _gtk_widget_lookup_for_size (GtkWidget *widget,
                              GtkIconSize icon_size)
 {
 	int w, h;
-	gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (widget),
-					   icon_size,
-					   &w, &h);
+	gtk_icon_size_lookup (icon_size,
+			      &w, &h);
 	return MAX (w, h);
 }
